'use strict';

const React = require('react');
const SearchInput = require('./search');
const { contactIcon, downloadIcon } = require('../nav-icons');

const TopPanel = ({ host, includeSearch, searchUrl, contactUrl, sections, downloadJmpValue, downloadUrl }) => React.createElement(
  'div',
  { className: 'nav-panel-top font--center' },
  React.createElement(
    'ul',
    { className: 'flex flex--space-between', style: { height: '100%' } },
    React.createElement(
      'div',
      { className: 'nav-panel-top__links flex flex--center-y font--center' },
      sections.map((section, i) => React.createElement(
        'a',
        {
          key: i,
          className: 'nav-panel-top__a',
          target: section.text === 'Open Source' && host === '' ? '_self' : '_blank',
          href: section.href },
        React.createElement(
          'li',
          { className: 'nav-panel-top__li' },
          section.text
        )
      ))
    ),
    React.createElement(
      'div',
      { className: 'flex flex--center-y' },
      React.createElement(
        'a',
        { href: contactUrl },
        React.createElement(
          'button',
          {
            className: 'flex flex--center-all flex--wrap nav-panel-top__contact',
            style: includeSearch ? {} : { marginRight: '15px' } },
          contactIcon
        )
      ),
      includeSearch && React.createElement(SearchInput, { searchUrl: searchUrl }),
      React.createElement(
        'a',
        {
          className: 'nav-panel-top__a',
          href: `${ host }${ downloadUrl }${ downloadJmpValue === '' ? '' : `?jmp=${ downloadJmpValue }` }`,
          target: host === '' ? '_self' : '_blank' },
        React.createElement(
          'button',
          { className: 'btn-small btn-fill btn-fill--light-green margin--left-xs nav-panel-top__download' },
          React.createElement(
            'span',
            { style: { verticalAlign: 'middle' } },
            'Download'
          ),
          downloadIcon
        )
      )
    )
  )
);

const { string, bool, array } = React.PropTypes;

TopPanel.propTypes = {
  includeSearch: bool,
  searchUrl: string,
  contactUrl: string,
  sections: array,
  host: string.isRequired,
  downloadUrl: string,
  downloadJmpValue: string
};

TopPanel.defaultProps = {
  includeSearch: true,
  searchUrl: '/search?search=',
  contactUrl: '/contact?jmp=nav',
  downloadUrl: '/download-center',
  downloadJmpValue: 'nav'
};

module.exports = TopPanel;