'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

const React = require('react');
const { VelocityComponent } = require('velocity-react');
const { searchIcon } = require('../nav-icons');

class SearchInput extends React.Component {
  constructor(props) {
    super(props);
    this.state = { isOpen: false };
    this.velocityConfig = {
      duration: 300,
      easing: 'easeOutQuint'
    };

    this.setState = this.setState.bind(this);
    this.onBtnPress = this.onBtnPress.bind(this);
    this.toggle = this.toggle.bind(this);
  }

  componentDidMount() {
    this.links = document.querySelector('.nav-panel-top__links');
  }

  onSearch() {
    const value = encodeURIComponent(this.refs.searchInput.value);
    window.location.href = `${ this.props.searchUrl }${ value }`;
  }

  onBtnPress(e) {
    e.preventDefault();
    e.stopPropagation();

    if (!this.state.isOpen) {
      this.refs.searchInput.focus();
      this.toggle(true);
    } else if (!this.refs.searchInput.value) {
      this.toggle(false);
    } else {
      this.onSearch();
    }
  }

  toggle(isOpen) {
    this.setState({ isOpen });
    this.links.classList.toggle('nav-panel-top__links--hidden', isOpen);
  }

  render() {
    const { isOpen } = this.state;

    return React.createElement(
      'span',
      { className: 'flex flex--wrap' },
      React.createElement(
        VelocityComponent,
        _extends({}, this.velocityConfig, {
          animation: isOpen ? { marginRight: '-35px', opacity: 1 } : { marginRight: '-210px', opacity: 0 } }),
        React.createElement('input', {
          className: 'input nav-panel-top__input',
          onBlur: () => window.setTimeout(() => this.toggle(false), 50),
          onKeyUp: e => e.keyCode === 13 && this.onSearch(),
          ref: 'searchInput',
          placeholder: 'search' })
      ),
      React.createElement(
        VelocityComponent,
        _extends({}, this.velocityConfig, {
          animation: isOpen ? { scale: 0.8 } : { scale: 1 } }),
        React.createElement(
          'button',
          {
            className: 'flex flex--center-all flex--wrap nav-panel-top__search',
            onClick: this.onBtnPress,
            onTouchStart: this.onBtnPress
          },
          searchIcon
        )
      )
    );
  }
}

const { string } = React.PropTypes;

SearchInput.propTypes = {
  searchUrl: string
};

module.exports = SearchInput;